==> libra_client-0.6.11-py3-none-any.whl: libra/cli/ledger_cmds.py <==
from libra.cli.command import *
from libra.cli.dual_command import DualCommand
from libra.wallet_library import WalletLibrary
from libra.transaction import SignedTransaction, Transaction
from datetime import datetime


class LedgerCmd(DualCommand):
    def get_aliases(self):
        return ["ledger", "lg"]

    def get_description(self):
        return "show ledger info of Libra blockchain"

    def execute(self, client, params, **kwargs):
        commands = [
            LedgerCmdInfo(),
            LedgerCmdTime()
        ]
        self.subcommand_execute(params[0], commands, client, params[1:], **kwargs)

    def get_real_client(self, client, **kwargs):
        if kwargs is not None and 'proxy' in kwargs:
            if kwargs['proxy']:
                return client.grpc_client
        return client


class LedgerCmdInfo(DualCommand):
    def get_aliases(self):
        return ["info", "i"]

    def get_description(self):
        return "Get the latest ledger info of Libra blockchain"

    def execute(self, client, params, **kwargs):
        client = self.get_real_client(client, **kwargs)
        info = client.get_latest_ledger_info()
        json_print_in_cmd(info)


class LedgerCmdTime(DualCommand):
    def get_aliases(self):
        return ["time", "t"]

    def get_description(self):
        return "Get the start and latest ledger time of Libra blockchain"

    def execute(self, client, params, **kwargs):
        client = self.get_real_client(client, **kwargs)
        request, resp = client._get_txs(1)
        info = resp.ledger_info_with_sigs.ledger_info
        txnp = resp.response_items[0].get_transactions_response.txn_list_with_proof
        tx = Transaction.deserialize(txnp.transactions[0].transaction)
        stx = tx.value
        start_time = datetime.fromtimestamp(stx.raw_txn.expiration_time)
        latest_time = datetime.fromtimestamp(client.latest_time / 1000_000)
        json_print_in_cmd({
            "start_time": start_time.strftime("%Y-%m-%dT%H:%M:%S"),
            "latest_time": latest_time.strftime("%Y-%m-%dT%H:%M:%S")
            }, sort_keys=False)

==> libra_client-0.6.13-py3-none-any.whl: libra/cli/ledger_cmds.py <==
from libra.cli.command import *
from libra.cli.dual_command import DualCommand
from libra.wallet_library import WalletLibrary
from libra.transaction import SignedTransaction, Transaction
from datetime import datetime


class LedgerCmd(DualCommand):
    def get_aliases(self):
        return ["ledger", "lg"]

    def get_description(self):
        return "show ledger info of Libra blockchain"

    def execute(self, client, params, **kwargs):
        commands = [
            LedgerCmdInfo(),
            LedgerCmdTime()
        ]
        self.subcommand_execute(params[0], commands, client, params[1:], **kwargs)

    def get_real_client(self, client, **kwargs):
        if kwargs is not None and 'proxy' in kwargs:
            if kwargs['proxy']:
                return client.grpc_client
        return client


class LedgerCmdInfo(DualCommand):
    def get_aliases(self):
        return ["info", "i"]

    def get_description(self):
        return "Get the latest ledger info of Libra blockchain"

    def execute(self, client, params, **kwargs):
        client = self.get_real_client(client, **kwargs)
        info = client.get_latest_ledger_info()
        json_print_in_cmd(info)


class LedgerCmdTime(DualCommand):
    def get_aliases(self):
        return ["time", "t"]

    def get_description(self):
        return "Get the start and latest ledger time of Libra blockchain"

    def execute(self, client, params, **kwargs):
        client = self.get_real_client(client, **kwargs)
        request, resp = client._get_txs(1)
        info = resp.ledger_info_with_sigs.ledger_info
        txnp = resp.response_items[0].get_transactions_response.txn_list_with_proof
        tx = Transaction.deserialize(txnp.transactions[0].transaction)
        stx = tx.value
        start_time = datetime.fromtimestamp(stx.timestamp_usec / 1000_000)
        latest_time = datetime.fromtimestamp(client.latest_time / 1000_000)
        json_print_in_cmd({
            "start_time": start_time.strftime("%Y-%m-%dT%H:%M:%S"),
            "latest_time": latest_time.strftime("%Y-%m-%dT%H:%M:%S")
            }, sort_keys=False)
